@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 package Data::Hive::Test;
-BEGIN {
-  $Data::Hive::Test::VERSION = '1.008';
+{
+  $Data::Hive::Test::VERSION = '1.009';
 }
 # ABSTRACT: a bundle of tests for Data::Hive stores
 
@@ -53,6 +53,8 @@ sub test_existing_hive {
 
       is($hive->one->GET,      1, "->one->GET is 1");
       is($hive->one->GET(10),  1, "->one->GET(10) is 1");
+
+      is($hive->one->GET(sub { 2 }),  1, "->one->GET(sub{2}) is 1");
     };
 
     subtest 'value of zero' => sub {
@@ -84,8 +86,9 @@ sub test_existing_hive {
 
       ok($hive->undef->EXISTS, "after being set, ->undef EXISTS");
 
-      is($hive->undef->GET,     undef, "->undef->GET is undef");
-      is($hive->undef->GET(10),    10, "->undef->GET(10) is undef");
+      is($hive->undef->GET,      undef, "->undef->GET is undef");
+      is($hive->undef->GET(10),     10, "->undef->GET(10) is 10");
+      is($hive->undef->GET(sub{2}),  2, "->undef->GET(sub{2}) is 2");
     };
 
     subtest 'non-existing value' => sub {
@@ -96,6 +99,7 @@ sub test_existing_hive {
       ok(! $hive->missing->EXISTS, "mere GET-ing won't cause ->missing to EXIST");
 
       is($hive->missing->GET(10),  10, "->missing->GET(10) is 10");
+      is($hive->missing->GET(sub{2}), 2, "->missing->GET(sub{2}) is 2");
     };
 
     subtest 'nested value' => sub {
@@ -215,6 +219,7 @@ sub test_existing_hive {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -223,7 +228,7 @@ Data::Hive::Test - a bundle of tests for Data::Hive stores
 
 =head1 VERSION
 
-version 1.008
+version 1.009
 
 =head1 SYNOPSIS
 
@@ -289,4 +294,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
